@@ -7,6 +7,7 @@
 #include "incidencemodel.h"
 #include <KLocalizedString>
 #include <QDebug>
+#include <KCalendarCore/Sorting>
 
 using namespace KCalendarCore;
 
@@ -113,7 +114,12 @@ QHash<int, QByteArray> IncidenceModel::roleNames() const
         { Due, "due" },
         { ValidStartDt, "validStartDt" },
         { ValidEndDt, "validEndDt" },
-        { ValidDueDt, "validDueDt" }
+        { ValidDueDt, "validDueDt" },
+        { AttendeeEmails, "attendeeEmails" },
+        { DisplayAttendeeEmails, "displayAttendeeEmails" },
+        { IncidenceStatus, "status" },
+        { OrganizerName, "organizerName" },
+        { DisplaytAttendeeNames, "displayAttendeeNames" }
     };
 }
 
@@ -190,6 +196,21 @@ QVariant IncidenceModel::data(const QModelIndex &index, int role) const
         return ((type == IncidenceBase::TypeEvent) && m_incidences.at(row).dynamicCast<Event>()->hasEndDate());
     case ValidDueDt:
         return ((type == IncidenceBase::TypeTodo) && m_incidences.at(row).dynamicCast<Todo>()->hasDueDate());
+    case AttendeeEmails:
+        return attendeeEmails(row);
+    case DisplayAttendeeEmails:
+        return attendeeEmails(row).join(QString {", "});
+    case IncidenceStatus:
+        return m_incidences.at(row)->status();
+    case OrganizerName: {
+        auto person = m_incidences.at(row)->organizer();
+        if (!(person.isEmpty()) && !(person.name().isEmpty())) {
+            return person.name();
+        }
+        return QString {};
+    }
+    case DisplaytAttendeeNames:
+        return attendeeNames(row).join(QString {", "});
     default:
         return QVariant();
     }
@@ -208,10 +229,9 @@ void IncidenceModel::loadIncidences()
 {
     beginResetModel();
     m_incidences.clear();
-
-    auto hourModelReady = (m_calendar != nullptr && m_filter_dt.isValid() && m_filter_hour >= 0);
-    auto dayModelReady = (m_calendar != nullptr && m_filter_dt.isValid());
-    auto allModelReady = (m_calendar != nullptr);
+    auto calendarReady = (m_calendar != nullptr) && (m_calendar->calendar() != nullptr);
+    auto dayModelReady = calendarReady && m_filter_dt.isValid();
+    auto hourModelReady = dayModelReady && (m_filter_hour >= 0);
 
     switch (m_filter_mode) {
     case FilterModes::HourIncidences: {
@@ -239,15 +259,15 @@ void IncidenceModel::loadIncidences()
         break;
     }
     case FilterModes::AllIncidences: {
-        m_incidences = (allModelReady) ? allIncidences() : m_incidences;
+        m_incidences = (calendarReady) ? allIncidences() : m_incidences;
         break;
     }
     case FilterModes::AllEvents: {
-        m_incidences = (allModelReady) ? allEvents() : m_incidences;
+        m_incidences = (calendarReady) ? allEvents() : m_incidences;
         break;
     }
     case FilterModes::AllTodos: {
-        m_incidences = (allModelReady) ? allTodos() : m_incidences;
+        m_incidences = (calendarReady) ? allTodos() : m_incidences;
         break;
     }
     case Invalid:
@@ -291,6 +311,7 @@ Incidence::List IncidenceModel::hourIncidences() const
 {
     auto incidences = hourEvents();
     incidences.append(hourTodos());
+    std::sort(incidences.begin(), incidences.end(), Incidences::dateLessThan);
 
     return incidences;
 }
@@ -397,40 +418,41 @@ Incidence::List IncidenceModel::dayIncidences() const
 {
     auto incidences = dayEvents();
     incidences.append(dayTodos());
+    std::sort(incidences.begin(), incidences.end(), Incidences::dateLessThan);
 
     return incidences;
 }
 
 Incidence::List IncidenceModel::dayEvents() const
 {
-    auto events = m_calendar->memorycalendar()->rawEventsForDate(m_filter_dt, QTimeZone::systemTimeZone(), EventSortStartDate, SortDirectionAscending);
+    auto events = m_calendar->calendar()->rawEventsForDate(m_filter_dt, QTimeZone::systemTimeZone(), EventSortStartDate, SortDirectionAscending);
     return toIncidences(Calendar::sortEvents(events, EventSortField::EventSortStartDate, SortDirection::SortDirectionAscending));
 }
 
 Incidence::List IncidenceModel::dayTodos() const
 {
-    auto todos =  m_calendar->memorycalendar()->rawTodos(m_filter_dt, m_filter_dt);
+    auto todos =  m_calendar->calendar()->rawTodos(m_filter_dt, m_filter_dt);
 
     return toIncidences(Calendar::sortTodos(todos, TodoSortField::TodoSortDueDate, SortDirection::SortDirectionAscending));
 }
 
 Incidence::List IncidenceModel::allIncidences() const
 {
-    auto incidences = m_calendar->memorycalendar()->rawIncidences();
+    auto incidences = m_calendar->calendar()->rawIncidences();
 
     return incidences;
 }
 
 Incidence::List IncidenceModel::allTodos() const
 {
-    auto todos =  m_calendar->memorycalendar()->todos(TodoSortDueDate, SortDirectionDescending);
+    auto todos =  m_calendar->calendar()->todos(TodoSortDueDate, SortDirectionDescending);
 
     return toIncidences(todos);
 }
 
 Incidence::List IncidenceModel::allEvents() const
 {
-    auto events = m_calendar->memorycalendar()->rawEvents(EventSortStartDate, SortDirectionDescending);
+    auto events = m_calendar->calendar()->rawEvents(EventSortStartDate, SortDirectionDescending);
 
     return toIncidences(events);
 }
@@ -568,9 +590,28 @@ void IncidenceModel::setFilterHideCompleted(const bool hideCompleted)
 
 void IncidenceModel::setCalendarFilter()
 {
-    if (m_calendar != nullptr) {
-        m_calendar->memorycalendar()->setFilter(m_cal_filter);
+    if ((m_calendar != nullptr) && (m_calendar->calendar() != nullptr)) {
+        m_calendar->calendar()->setFilter(m_cal_filter);
+        Q_EMIT calendarFilterChanged();
     }
+}
 
-    Q_EMIT calendarFilterChanged();
+QStringList IncidenceModel::attendeeEmails(const int idx) const
+{
+    auto attendees = m_incidences.at(idx)->attendees();
+    QStringList emails {};
+    for (const auto &a : attendees) {
+        emails.append(a.email());
+    }
+    return emails;
+}
+
+QStringList IncidenceModel::attendeeNames(const int idx) const
+{
+    auto attendees = m_incidences.at(idx)->attendees();
+    QStringList names {};
+    for (const auto &a : attendees) {
+        names.append(a.name());
+    }
+    return names;
 }
